@@ -31,7 +31,7 @@ def parse(text, meta):
     meta['fulltoc'] = tocbuilder.fulltoc()
     html = root.render(meta)
     html = escapes.unescapechars(html)
-    return html, root, meta
+    return html.strip(), root, meta
 
 
 # ------------------------------------------------------------------------------
@@ -61,7 +61,7 @@ Usage: %s [FLAGS] [OPTIONS]
     $ syntext < input.txt > output.html
 
 Options:
-  -t, --tabsize <n>     Set tabsize (default: 4).
+  -t, --tabsize <n>     Set tab translation size (default: 4).
 
 Flags:
   -d, --debug           Run in debug mode.
@@ -117,7 +117,7 @@ def main():
         print(utils.title('META'))
         print(pprint.pformat(meta) + '\n')
         print(utils.title('HTML'))
-        print(html.strip())
+        print(html)
     else:
         print(html)
 
